# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system

Self = typing.TypeVar('Self')

@typing.final
class Color:
    @_property
    def a(self) -> winrt.system.UInt8: ...
    @_property
    def r(self) -> winrt.system.UInt8: ...
    @_property
    def g(self) -> winrt.system.UInt8: ...
    @_property
    def b(self) -> winrt.system.UInt8: ...
    def __new__(cls, a: winrt.system.UInt8 = 0, r: winrt.system.UInt8 = 0, g: winrt.system.UInt8 = 0, b: winrt.system.UInt8 = 0) -> Color: ...
    def __replace__(self, /, **changes: typing.Any) -> Color: ...
    def unpack(self) -> typing.Tuple[winrt.system.UInt8, winrt.system.UInt8, winrt.system.UInt8, winrt.system.UInt8]: ...

@typing.final
class WindowId:
    @_property
    def value(self) -> winrt.system.UInt64: ...
    def __new__(cls, value: winrt.system.UInt64 = 0) -> WindowId: ...
    def __replace__(self, /, **changes: typing.Any) -> WindowId: ...

@typing.final
class ColorHelper_Static(winrt._winrt.IInspectable_Static):
    # Windows.UI.Color Windows.UI.ColorHelper::FromArgb(System.Byte,System.Byte,System.Byte,System.Byte)
    def from_argb(cls, a: winrt.system.UInt8, r: winrt.system.UInt8, g: winrt.system.UInt8, b: winrt.system.UInt8, /) -> Color: ...
    # System.String Windows.UI.ColorHelper::ToDisplayName(Windows.UI.Color)
    def to_display_name(cls, color: typing.Union[Color, typing.Tuple[winrt.system.UInt8, winrt.system.UInt8, winrt.system.UInt8, winrt.system.UInt8]], /) -> str: ...

@typing.final
class ColorHelper(winrt.system.Object, metaclass=ColorHelper_Static):
    pass

@typing.final
class Colors_Static(winrt._winrt.IInspectable_Static):
    # Windows.UI.Color Windows.UI.Colors::get_AliceBlue()
    @_property
    def alice_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_AntiqueWhite()
    @_property
    def antique_white(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Aqua()
    @_property
    def aqua(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Aquamarine()
    @_property
    def aquamarine(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Azure()
    @_property
    def azure(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Beige()
    @_property
    def beige(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Bisque()
    @_property
    def bisque(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Black()
    @_property
    def black(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_BlanchedAlmond()
    @_property
    def blanched_almond(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Blue()
    @_property
    def blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_BlueViolet()
    @_property
    def blue_violet(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Brown()
    @_property
    def brown(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_BurlyWood()
    @_property
    def burly_wood(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_CadetBlue()
    @_property
    def cadet_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Chartreuse()
    @_property
    def chartreuse(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Chocolate()
    @_property
    def chocolate(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Coral()
    @_property
    def coral(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_CornflowerBlue()
    @_property
    def cornflower_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Cornsilk()
    @_property
    def cornsilk(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Crimson()
    @_property
    def crimson(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Cyan()
    @_property
    def cyan(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkBlue()
    @_property
    def dark_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkCyan()
    @_property
    def dark_cyan(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkGoldenrod()
    @_property
    def dark_goldenrod(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkGray()
    @_property
    def dark_gray(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkGreen()
    @_property
    def dark_green(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkKhaki()
    @_property
    def dark_khaki(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkMagenta()
    @_property
    def dark_magenta(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkOliveGreen()
    @_property
    def dark_olive_green(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkOrange()
    @_property
    def dark_orange(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkOrchid()
    @_property
    def dark_orchid(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkRed()
    @_property
    def dark_red(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkSalmon()
    @_property
    def dark_salmon(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkSeaGreen()
    @_property
    def dark_sea_green(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkSlateBlue()
    @_property
    def dark_slate_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkSlateGray()
    @_property
    def dark_slate_gray(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkTurquoise()
    @_property
    def dark_turquoise(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DarkViolet()
    @_property
    def dark_violet(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DeepPink()
    @_property
    def deep_pink(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DeepSkyBlue()
    @_property
    def deep_sky_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DimGray()
    @_property
    def dim_gray(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_DodgerBlue()
    @_property
    def dodger_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Firebrick()
    @_property
    def firebrick(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_FloralWhite()
    @_property
    def floral_white(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_ForestGreen()
    @_property
    def forest_green(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Fuchsia()
    @_property
    def fuchsia(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Gainsboro()
    @_property
    def gainsboro(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_GhostWhite()
    @_property
    def ghost_white(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Gold()
    @_property
    def gold(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Goldenrod()
    @_property
    def goldenrod(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Gray()
    @_property
    def gray(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Green()
    @_property
    def green(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_GreenYellow()
    @_property
    def green_yellow(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Honeydew()
    @_property
    def honeydew(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_HotPink()
    @_property
    def hot_pink(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_IndianRed()
    @_property
    def indian_red(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Indigo()
    @_property
    def indigo(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Ivory()
    @_property
    def ivory(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Khaki()
    @_property
    def khaki(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Lavender()
    @_property
    def lavender(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LavenderBlush()
    @_property
    def lavender_blush(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LawnGreen()
    @_property
    def lawn_green(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LemonChiffon()
    @_property
    def lemon_chiffon(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LightBlue()
    @_property
    def light_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LightCoral()
    @_property
    def light_coral(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LightCyan()
    @_property
    def light_cyan(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LightGoldenrodYellow()
    @_property
    def light_goldenrod_yellow(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LightGray()
    @_property
    def light_gray(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LightGreen()
    @_property
    def light_green(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LightPink()
    @_property
    def light_pink(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LightSalmon()
    @_property
    def light_salmon(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LightSeaGreen()
    @_property
    def light_sea_green(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LightSkyBlue()
    @_property
    def light_sky_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LightSlateGray()
    @_property
    def light_slate_gray(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LightSteelBlue()
    @_property
    def light_steel_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LightYellow()
    @_property
    def light_yellow(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Lime()
    @_property
    def lime(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_LimeGreen()
    @_property
    def lime_green(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Linen()
    @_property
    def linen(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Magenta()
    @_property
    def magenta(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Maroon()
    @_property
    def maroon(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_MediumAquamarine()
    @_property
    def medium_aquamarine(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_MediumBlue()
    @_property
    def medium_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_MediumOrchid()
    @_property
    def medium_orchid(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_MediumPurple()
    @_property
    def medium_purple(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_MediumSeaGreen()
    @_property
    def medium_sea_green(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_MediumSlateBlue()
    @_property
    def medium_slate_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_MediumSpringGreen()
    @_property
    def medium_spring_green(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_MediumTurquoise()
    @_property
    def medium_turquoise(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_MediumVioletRed()
    @_property
    def medium_violet_red(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_MidnightBlue()
    @_property
    def midnight_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_MintCream()
    @_property
    def mint_cream(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_MistyRose()
    @_property
    def misty_rose(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Moccasin()
    @_property
    def moccasin(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_NavajoWhite()
    @_property
    def navajo_white(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Navy()
    @_property
    def navy(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_OldLace()
    @_property
    def old_lace(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Olive()
    @_property
    def olive(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_OliveDrab()
    @_property
    def olive_drab(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Orange()
    @_property
    def orange(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_OrangeRed()
    @_property
    def orange_red(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Orchid()
    @_property
    def orchid(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_PaleGoldenrod()
    @_property
    def pale_goldenrod(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_PaleGreen()
    @_property
    def pale_green(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_PaleTurquoise()
    @_property
    def pale_turquoise(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_PaleVioletRed()
    @_property
    def pale_violet_red(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_PapayaWhip()
    @_property
    def papaya_whip(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_PeachPuff()
    @_property
    def peach_puff(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Peru()
    @_property
    def peru(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Pink()
    @_property
    def pink(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Plum()
    @_property
    def plum(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_PowderBlue()
    @_property
    def powder_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Purple()
    @_property
    def purple(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Red()
    @_property
    def red(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_RosyBrown()
    @_property
    def rosy_brown(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_RoyalBlue()
    @_property
    def royal_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_SaddleBrown()
    @_property
    def saddle_brown(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Salmon()
    @_property
    def salmon(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_SandyBrown()
    @_property
    def sandy_brown(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_SeaGreen()
    @_property
    def sea_green(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_SeaShell()
    @_property
    def sea_shell(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Sienna()
    @_property
    def sienna(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Silver()
    @_property
    def silver(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_SkyBlue()
    @_property
    def sky_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_SlateBlue()
    @_property
    def slate_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_SlateGray()
    @_property
    def slate_gray(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Snow()
    @_property
    def snow(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_SpringGreen()
    @_property
    def spring_green(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_SteelBlue()
    @_property
    def steel_blue(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Tan()
    @_property
    def tan(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Teal()
    @_property
    def teal(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Thistle()
    @_property
    def thistle(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Tomato()
    @_property
    def tomato(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Transparent()
    @_property
    def transparent(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Turquoise()
    @_property
    def turquoise(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Violet()
    @_property
    def violet(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Wheat()
    @_property
    def wheat(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_White()
    @_property
    def white(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_WhiteSmoke()
    @_property
    def white_smoke(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_Yellow()
    @_property
    def yellow(cls) -> Color: ...
    # Windows.UI.Color Windows.UI.Colors::get_YellowGreen()
    @_property
    def yellow_green(cls) -> Color: ...

@typing.final
class Colors(winrt.system.Object, metaclass=Colors_Static):
    pass

@typing.final
class UIContentRoot(winrt.system.Object):
    # Windows.UI.UIContext Windows.UI.UIContentRoot::get_UIContext()
    @_property
    def ui_context(self) -> UIContext: ...

@typing.final
class UIContext(winrt.system.Object):
    pass




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import winrt.system
from winrt._winrt_windows_ui import (
    Color,
    WindowId,
    ColorHelper,
    Colors,
    UIContentRoot,
    UIContext,
)

__all__ = [
    "Color",
    "WindowId",
    "ColorHelper",
    "Colors",
    "UIContentRoot",
    "UIContext",
]

